@@ -1,6 +1,5 @@
+import warnings
 import click
-import yaml
-from yaml.loader import SafeLoader
 from os.path import exists
 import os
 import datetime
@@ -10,13 +9,16 @@ import logging
 import requests
 from pydrive.auth import GoogleAuth
 from pydrive.drive import GoogleDrive
-from decouple import config
+# from decouple import config
 from pybtex.database import BibliographyData, Entry
+from dotenv import load_dotenv
 
-apiKey = config('monday_apikey')
-apiUrl = "https://api.monday.com/v2"
+
+load_dotenv(os.getcwd() +'/.env')
+apiKey = os.environ.get('monday_apikey')
+apiUrl = os.environ.get('API_URL')
 headers = {"Authorization": apiKey, "Content-Type ": "application/json"}
-
+non_confermance_board_id = os.environ.get('non_conformance_id')
 
 @click.group()
 def main():
@@ -36,32 +38,95 @@ def cli():
         #              'repo_description': yaml_data[0]['description'],'flag':'flat'}]
         yml_data = [{'client': 'sigil', 'repo_name': 'AUDIT_DOG',
                      'repo_description': 'An audit agent for policy compliance inspection across projects',
-                     'flag': 'flat'}]
+                     'flag': 'flat','monday_norconfermance_url':'https://mtg-research-and-development-lab.monday.com/boards/2494152527',
+                     'gitlab_repo_url':'https://gitlab.com/sigil-scientific-enterprises/audit-dog',
+                     'google_workspace_url':'https://drive.google.com/drive/my-drive',
+                     'non_confermance_board_id':non_confermance_board_id}]
         CreateFileInRepo('audit-dog.yml', yml_data)
         # with open('audit-dog.yml', 'w') as f:
         #     data = yaml.dump(yml_data, f, sort_keys=False, default_flow_style=False)
         #     print(data)
 
+    file_exists = exists(os.getcwd() + '/gitlab-ci.yml')
 
 @main.command()
-def run():
-    name = GetBoardFromGitlab()
-    non_conformance_id = config('non_conformance_id')
+@click.option('--flag', type=click.Choice(['flat', 'modular'], case_sensitive=False), default='flat')
+def run(flag):
+    non_conformance_id = os.environ.get('non_conformance_id')
     gauth = GoogleAuth()
     gauth.LocalWebserverAuth()
     drive = GoogleDrive(gauth)
 
-    folder_list = []
-    # get all folder name
-    f = drive.ListFile({"q": "mimeType='application/vnd.google-apps.folder' and trashed=false"}).GetList()
-    for folder in f:
-        folder_list.append(folder['title'])
+    flat_folder_list = ['Abstracts',
+                        'Data Partners',
+                        'Documentation',
+                        'Manuscripts',
+                        'Outputs',
+                        'Posters',
+                        'Presentations',
+                        'References',
+                        'Reports',
+                        'Test Slide Deck.pptx',
+                        'Test Study Protocol.pdf'
+                        ]
 
-    if name not in folder_list:
-        # Create folder
-        folder_metadata = {'title': name, 'mimeType': 'application/vnd.google-apps.folder'}
-        folder = drive.CreateFile(folder_metadata)
-        folder.Upload()
+    folder_list = []
+    if flag == 'flat':
+        # get all folder name
+        f = drive.ListFile({
+                               "q": "mimeType='application/vnd.google-apps.folder' or mimeType='applicationvnd.google-apps.folder' and trashed=false"}).GetList()
+        for folder in f:
+            folder_list.append(folder['title'])
+        for name in flat_folder_list:
+            # Create folder
+
+            if name not in folder_list:
+                # Create folder
+                folder_metadata = {'title': name, 'mimeType': 'applicationvnd.google-apps.folder'}
+                if name.endswith('.pptx') or name.endswith('.pdf'):
+                    folder = drive.CreateFile(folder_metadata)
+                    folder.Upload()
+                else:
+                    folder = drive.CreateFile({'title': name, 'mimeType': 'application/vnd.google-apps.folder'})
+                    folder.Upload()
+    if flag == 'modular':
+        module_name = ['module_A', 'module_B', 'Test Slide Deck.pptx', 'Test Study Protocol.pdf']
+        module_folder_inside_structure = ['Abstracts',
+                                          'Data Partners',
+                                          'Documentation',
+                                          'Manuscripts',
+                                          'Outputs',
+                                          'Posters',
+                                          'Presentations',
+                                          'References',
+                                          'Reports'
+                                          ]
+        module_name_list = []
+        module_id = []
+        # get all folder name
+        f = drive.ListFile({
+            "q": "mimeType='application/vnd.google-apps.folder' or mimeType='applicationvnd.google-apps.folder'  and trashed=false"}).GetList()
+        for folder in f:
+            module_name_list.append(folder['title'])
+            module_id.append(folder['id'])
+
+        for m_name in module_name:
+            if m_name not in module_name_list:
+                parent_folder = drive.CreateFile({'title': m_name, 'mimeType': 'applicationvnd.google-apps.folder'})
+                if m_name.endswith('.pptx') or m_name.endswith('.pdf'):
+                    folder = drive.CreateFile(parent_folder)
+                    folder.Upload()
+
+                else:
+                    folder = drive.CreateFile({'title': m_name, 'mimeType': 'application/vnd.google-apps.folder'})
+                    folder.Upload()
+
+        for flat_name in module_folder_inside_structure:
+            for module_id in module_id:
+                if flat_name not in module_name_list or module_id not in module_id:
+                    folder_metadata = drive.CreateFile({'title': flat_name, "parents": [{'id': module_id}],
+                                                        'mimeType': 'application/vnd.google-apps.folder'})
+                    folder_metadata.Upload()
 
     # Get folder info and print to screen
     foldertitle = folder['title']
@@ -115,23 +180,34 @@ def run():
 
 @main.command()
 def seed():
+    """ spec.yml is creating.
+        capabilities.yml is creating.
+        env.yml is creating
+        references.yml is creating """
+
     file_exists = exists(os.getcwd() + '/spec.yml')
     if not file_exists:
         yml_data = [{'version': '0.2', 'privacy': 'confidential',
                      'confidential': 'Study Protocol'}]
         CreateFileInRepo('spec.yml', yml_data)
+    if file_exists:
+        warnings.warn('File Already Exists spec.yml')
 
     file_exists = exists(os.getcwd() + '/capabilities.yml')
     if not file_exists:
         yml_data = [{'name': 'audit dog', 'title': 'Audit Dog',
                      'long': 'AuditDog'}]
         CreateFileInRepo('capabilities.yml', yml_data)
+    if file_exists:
+        warnings.warn('File Already Exists capabilities.yml')
 
     file_exists = exists(os.getcwd() + '/env.yml')
     if not file_exists:
         yml_data = [{'name': 'audit dog', 'title': 'Audit Dog',
                      'long': 'AuditDog'}]
         CreateFileInRepo('env.yml', yml_data)
+    if file_exists:
+        warnings.warn('File Already Exists env.yml')
 
     file_exists = exists(os.getcwd() + '/references.bib')
     if not file_exists:
@@ -145,27 +221,20 @@ def seed():
         })
 
         bib_data.to_file(file='references.bib', bib_format='bibtex')
+    if file_exists:
+        warnings.warn('File Already Exists references.bib')
 
     if not os.path.exists('assets'):
         os.mkdir('assets')
-        print("Directory ", 'assets', " Created ")
 
-    file_exists = exists(os.getcwd() + '/README.yml')
-    if not file_exists:
-        yml_data = ['An audit agent for policy compliance inspection across projects and teams./n/n **Workinks** /n [Gitlab](https://gitlab.com/sigil-scientific-enterprises/audit-dog)']
-        CreateFileInRepo('env.yml', yml_data)
 
     file_exists = exists(os.getcwd() + '/README.md')
     if not file_exists:
         yml_data = 'An audit agent for policy compliance inspection across projects and teams.\n\n **Workinks** \n\n [Gitlab](https://gitlab.com/sigil-scientific-enterprises/audit-dog)'
         with open('README.md', 'w') as f:
             f.write(yml_data)
-
-    """ spec.yml is creating.
-    capabilities.yml is creating.
-    env.yml is creating
-    references.yml is creating """
-
+    if file_exists:
+        warnings.warn('File Already Exists README.md')
 
 def CreateFileInRepo(filename, yml_data):
     with open(filename, 'w') as f:
@@ -175,8 +244,8 @@ def CreateFileInRepo(filename, yml_data):
 
 def GetBoardFromGitlab():  # for getting repository information
     logging.info('This is in GetBoardFromGitlab function')
-    url = config('gitlab_url')
-    token = config('gitlab_token')
+    url = os.environ.get('gitlab_url')
+    token = os.environ.get('gitlab_token')
     headers1 = {"Authorization": token}
     r = requests.get(url=url, headers=headers1)
     jsondata = r.json()
